@@ -6,12 +6,12 @@ from steinbock.classification.ilastik.ilastik import (
     write_ilastik_image,
     write_ilastik_crop,
     create_ilastik_image,
-    create_ilastik_images_from_disk,
+    try_create_ilastik_images_from_disk,
     create_ilastik_crop,
-    create_ilastik_crops_from_disk,
+    try_create_ilastik_crops_from_disk,
     create_and_save_ilastik_project,
     run_pixel_classification,
-    fix_ilastik_crops_from_disk,
+    try_fix_ilastik_crops_from_disk,
     fix_ilastik_project_file_inplace,
 )
 
@@ -24,11 +24,11 @@ __all__ = [
     "write_ilastik_image",
     "write_ilastik_crop",
     "create_ilastik_image",
-    "create_ilastik_images_from_disk",
+    "try_create_ilastik_images_from_disk",
     "create_ilastik_crop",
-    "create_ilastik_crops_from_disk",
+    "try_create_ilastik_crops_from_disk",
     "create_and_save_ilastik_project",
     "run_pixel_classification",
-    "fix_ilastik_crops_from_disk",
+    "try_fix_ilastik_crops_from_disk",
     "fix_ilastik_project_file_inplace",
 ]
