@@ -1,6 +1,6 @@
 from steinbock.measurement.cellprofiler.cellprofiler import (
     create_and_save_measurement_pipeline,
-    run_object_measurement,
+    measure_objects,
 )
 
-__all__ = ["create_and_save_measurement_pipeline", "run_object_measurement"]
+__all__ = ["create_and_save_measurement_pipeline", "measure_objects"]
