@@ -1,6 +1,6 @@
 from steinbock.segmentation.cellprofiler.cellprofiler import (
     create_and_save_segmentation_pipeline,
-    run_object_segmentation,
+    try_segment_objects,
 )
 
-__all__ = ["create_and_save_segmentation_pipeline", "run_object_segmentation"]
+__all__ = ["create_and_save_segmentation_pipeline", "try_segment_objects"]
